@@ -21,7 +21,12 @@ from Qt import QtWidgets, QtCore
 
 
 class HandlerBase(object):
-    pass
+    def __rrshift__(self, _):
+        binding = Binding._inst_.pop()
+        self.handle(binding)
+
+    def handle(self, binding):
+        raise NotImplementedError
 
 
 class ItemMeta(type):
@@ -30,16 +35,14 @@ class ItemMeta(type):
         cls.item = item
         return cls
 
-@six.add_metaclass(ItemMeta)
-class ItemConstructor(HandlerBase):
+
+class ItemConstructor(HandlerBase, six.with_metaclass(ItemMeta)):
     def __init__(self, *args, **kwargs):
         self.args = args
         self.kwargs = kwargs
 
     def __rrshift__(self, item_data):
-        # binding = Binding._inst_.pop()
-
-        # NOTE trace lamda function
+        # NOTE trace lambda function
         filters = self.kwargs.pop("__filters__", [i for i in range(len(item_data))])
         if callable(filters):
             # NOTE make sure handle list data
@@ -47,6 +50,7 @@ class ItemConstructor(HandlerBase):
 
         layout = self.kwargs.pop("__layout__")
         binder_name = self.kwargs.pop("__binder__")
+        index = self.kwargs.pop("__index__", 0)
 
         if not hasattr(layout, "__items__"):
             layout.__items__ = []
@@ -55,31 +59,39 @@ class ItemConstructor(HandlerBase):
             widget = layout.__items__ >> ListGet(i)
             if not widget:
                 widget = self.item(*self.args, **self.kwargs)
-                layout.addWidget(widget)
+                layout.insertWidget(i + index, widget)
                 layout.__items__.append(widget)
-                if hasattr(widget,"__item__"):
-                    widget.__item__(i,item_data)
+                if hasattr(widget, "__item__"):
+                    widget.__item__(i, item_data, layout)
 
             widget.setVisible(i in filters)
 
             if hasattr(widget, binder_name):
-                binder = getattr(widget, binder_name)
-                for k, v in data.items():
-                    val = getattr(binder, k)
-                    setattr(binder, k, v)
+                # NOTE delay update
+                QtCore.QTimer.singleShot(
+                    0, partial(self._update_value_, data, widget, binder_name)
+                )
 
-        for i in range(len(item_data), len(layout.__items__)):
+        for i in reversed(range(len(item_data), len(layout.__items__))):
             widget = layout.__items__[i]
-            widget.deleteLater()
-        layout.__items__ = layout.__items__[: len(item_data)]
+            widget.hide()
+        # layout.__items__ = layout.__items__[: len(item_data)]
+
+    def _update_value_(self, data, widget, binder_name):
+        binder = getattr(widget, binder_name)
+        for k, v in data.items():
+            val = getattr(binder, k)
+            # NOTE avoid infinite loop
+            if val != v:
+                setattr(binder, k, v)
 
 
 class GroupBoxBind(HandlerBase):
     def __init__(self, group):
         self.group = group
 
-    def __rrshift__(self, binding):
-        self.binding = Binding._inst_.pop()
+    def handle(self, binding):
+        self.binding = binding
         for rb in self.group.findChildren(QtWidgets.QRadioButton):
             rb.toggled.connect(partial(self.filter_state, rb))
         self.binding.connect(self.check_state) >> Call()
@@ -87,8 +99,7 @@ class GroupBoxBind(HandlerBase):
         return self.binding
 
     def filter_state(self, rb, state):
-        if state:
-            self.binding.set(rb.text().strip())
+        state and self.binding.set(rb.text().strip())
 
     def check_state(self):
         for rb in self.group.findChildren(QtWidgets.QRadioButton):
@@ -109,8 +120,7 @@ class Set(HandlerBase):
     def __init__(self, val):
         self.val = val
 
-    def __rrshift__(self, binding):
-        binding = Binding._inst_.pop()
+    def handle(self, binding):
         binding.set(self.val)
         return binding
 
@@ -142,18 +152,17 @@ class Anim(HandlerBase):
         self.finished = finished
         self.easing = easing
 
-    def __rrshift__(self, binding):
-        binding = Binding._inst_.pop()
+    def handle(self, binding):
         data = binding.get()
         data_list = data if isinstance(data, Iterable) else [data]
 
         anim_list = []
-        for i, (start,value) in enumerate(zip(data_list,self.value_list)):
+        for i, (start, value) in enumerate(zip(data_list, self.value_list)):
             anim = QAnim()
             anim_list.append(anim)
             anim.setDuration(self.duration)
-            
-            def value_change(i,v):
+
+            def value_change(i, v):
                 value = binding.get()
                 if not isinstance(value, Iterable):
                     binding.set(v)
@@ -161,7 +170,7 @@ class Anim(HandlerBase):
                     value[i] = v
                     binding.set(value)
 
-            anim.valueChanged.connect(partial(value_change,i))
+            anim.valueChanged.connect(partial(value_change, i))
             anim.finished.connect(anim.deleteLater)
             anim.setEasingCurve(self.easing)
 
